@@ -42,16 +42,32 @@ def list_elbv2(ec2, region):
       load_balancer_type = response.get('LoadBalancers')[elb].get('Type')
       load_balancer_tg = client.describe_target_groups(LoadBalancerArn=load_balancer_arn)
       elb_branch = tree.add(":file_folder:[bold white] "+load_balancer_name+" Type: "+load_balancer_type)
-      tg_folder = elb_branch.add("Target Groups")
+      tg_folder = elb_branch.add(":file_folder: Target Groups")
       for tg in range(len(load_balancer_tg.get('TargetGroups'))):
           tg_dict = load_balancer_tg.get('TargetGroups')[tg]
-          tg_branch = tg_folder.add("[bold white]"+tg_dict.get('TargetGroupName')+" [not bold]Type: "+tg_dict.get('TargetType'))
+          tg_branch = tg_folder.add(":file_folder:[bold white] "+tg_dict.get('TargetGroupName')+" [not bold]Type: "+tg_dict.get('TargetType'))
           target_health = client.describe_target_health(TargetGroupArn=tg_dict.get('TargetGroupArn'))
           for t in range(len(target_health.get('TargetHealthDescriptions'))):
               target_id=target_health.get('TargetHealthDescriptions')[t].get('Target').get('Id')
               target_state=target_health.get('TargetHealthDescriptions')[t].get('TargetHealth').get('State')
               target_state_desc=target_health.get('TargetHealthDescriptions')[t].get('TargetHealth').get('Description')
-              t_branch = tg_branch.add("[cyan]"+target_id+" [white]Status: "+target_state+" Description: "+target_state_desc)
+              # Target Type: instance'|'ip'|'lambda'|'alb'
+              if tg_dict.get('TargetType') == 'instance':
+                  target_name=get_name_tag(ec2, target_id)
+              elif tg_dict.get('TargetType') == 'ip':
+                  target_name="ip"
+              elif tg_dict.get('TargetType') == 'lambda':
+                  target_name="lambda"
+              elif tg_dict.get('TargetType') == 'alb':
+                  target_name="alb"
+              # TargetHealth State: initial'|'healthy'|'unhealthy'|'unused'|'draining'|'unavailable'
+              if target_state == 'healthy':
+                  target_state = "[green]"+target_state
+              elif target_state == 'unhealthy':
+                  target_state = "[red]"+target_state
+              else:
+                  target_state = "[orange1]"+target_state
+              tg_branch.add("[cyan]"+target_id+" [white]("+target_name+") [white]Status: "+target_state+" [white]Description: "+target_state_desc)
     print(tree)
 
 def main():
